@@ -1,22 +1,22 @@
 import collections
 import contextlib
-import inspect
 import functools
+import inspect
 import json as pyjson
 import logging
 import os
 import re
 import typing
-import types
+import warnings
 from collections.abc import Mapping
 from enum import Enum
-from urllib.parse import urlparse, ParseResult
 from pathlib import Path
+from urllib.parse import ParseResult, urlparse
 
 import marshmallow as ma
-from dotenv.main import load_dotenv, _walk_to_root
+from dotenv.main import _walk_to_root, load_dotenv
 
-__version__ = "9.2.0"
+__version__ = "9.5.0"
 __all__ = ["EnvError", "Env"]
 
 
@@ -28,7 +28,7 @@ _IntType = int
 ErrorMapping = typing.Mapping[str, typing.List[str]]
 ErrorList = typing.List[str]
 FieldFactory = typing.Callable[..., ma.fields.Field]
-Subcast = typing.Union[typing.Type, typing.Callable[..., _T]]
+Subcast = typing.Union[typing.Type, typing.Callable[..., _T], ma.fields.Field]
 FieldType = typing.Type[ma.fields.Field]
 FieldOrFactory = typing.Union[FieldType, FieldFactory]
 ParserMethod = typing.Callable
@@ -55,39 +55,71 @@ class ParserConflictError(ValueError):
     """Raised when adding a custom parser that conflicts with a built-in parser method."""
 
 
+_SUPPORTS_LOAD_DEFAULT = ma.__version_info__ >= (3, 13)
+
+
 def _field2method(
-    field_or_factory: FieldOrFactory, method_name: str, *, preprocess: typing.Optional[typing.Callable] = None
+    field_or_factory: FieldOrFactory,
+    method_name: str,
+    *,
+    preprocess: typing.Optional[typing.Callable] = None,
+    preprocess_kwarg_names: typing.Sequence[str] = tuple(),
 ) -> ParserMethod:
     def method(
         self: "Env",
         name: str,
         default: typing.Any = ma.missing,
         subcast: typing.Optional[Subcast] = None,
+        *,
+        # Subset of relevant marshmallow.Field kwargs
+        load_default: typing.Any = ma.missing,
+        missing: typing.Any = ma.missing,
+        validate: typing.Optional[
+            typing.Union[
+                typing.Callable[[typing.Any], typing.Any],
+                typing.Iterable[typing.Callable[[typing.Any], typing.Any]],
+            ]
+        ] = None,
+        required: bool = False,
+        allow_none: typing.Optional[bool] = None,
+        error_messages: typing.Optional[typing.Dict[str, str]] = None,
+        metadata: typing.Optional[typing.Mapping[str, typing.Any]] = None,
         **kwargs,
     ) -> typing.Optional[_T]:
         if self._sealed:
             raise EnvSealedError("Env has already been sealed. New values cannot be parsed.")
-        missing = kwargs.pop("missing", None) or default
-        if isinstance(field_or_factory, type) and issubclass(field_or_factory, ma.fields.Field):
-            field = field_or_factory(missing=missing, **kwargs)
+        field_kwargs = dict(
+            validate=validate,
+            required=required,
+            allow_none=allow_none,
+            error_messages=error_messages,
+            metadata=metadata,
+        )
+        preprocess_kwargs = {name: kwargs.pop(name) for name in preprocess_kwarg_names if name in kwargs}
+        if _SUPPORTS_LOAD_DEFAULT:
+            field_kwargs["load_default"] = load_default or default
         else:
-            field = field_or_factory(subcast=subcast, missing=missing, **kwargs)
-        parsed_key, raw_value, proxied_key = self._get_from_environ(name, ma.missing)
+            field_kwargs["missing"] = missing or default
+        if isinstance(field_or_factory, type) and issubclass(field_or_factory, ma.fields.Field):
+            # TODO: Remove `type: ignore` after https://github.com/python/mypy/issues/9676 is fixed
+            field = field_or_factory(**field_kwargs, **kwargs)  # type: ignore
+        else:
+            parsed_subcast = _make_subcast_field(subcast)
+            field = field_or_factory(subcast=parsed_subcast, **field_kwargs)
+        parsed_key, value, proxied_key = self._get_from_environ(
+            name, field.load_default if _SUPPORTS_LOAD_DEFAULT else field.missing
+        )
         self._fields[parsed_key] = field
         source_key = proxied_key or parsed_key
-        if raw_value is ma.missing and field.missing is ma.missing:
+        if value is ma.missing:
             if self.eager:
                 raise EnvError('Environment variable "{}" not set'.format(proxied_key or parsed_key))
             else:
                 self._errors[parsed_key].append("Environment variable not set.")
                 return None
-        if raw_value or raw_value == "":
-            value = raw_value
-        else:
-            value = field.missing if field.missing is not ma.missing else None
-        if preprocess:
-            value = preprocess(value, subcast=subcast, **kwargs)
         try:
+            if preprocess:
+                value = preprocess(value, **preprocess_kwargs)
             value = field.deserialize(value)
         except ma.ValidationError as error:
             if self.eager:
@@ -114,7 +146,7 @@ def _func2method(func: typing.Callable, method_name: str) -> ParserMethod:
         if self._sealed:
             raise EnvSealedError("Env has already been sealed. New values cannot be parsed.")
         parsed_key, raw_value, proxied_key = self._get_from_environ(name, default)
-        self._fields[parsed_key] = ma.fields.Field(**kwargs)
+        self._fields[parsed_key] = ma.fields.Field()
         source_key = proxied_key or parsed_key
         if raw_value is ma.missing:
             if self.eager:
@@ -143,8 +175,26 @@ def _func2method(func: typing.Callable, method_name: str) -> ParserMethod:
     return method
 
 
+def _make_subcast_field(subcast: typing.Optional[Subcast]) -> typing.Type[ma.fields.Field]:
+    if isinstance(subcast, type) and subcast in ma.Schema.TYPE_MAPPING:
+        inner_field = ma.Schema.TYPE_MAPPING[subcast]
+    elif isinstance(subcast, type) and issubclass(subcast, ma.fields.Field):
+        inner_field = subcast
+    elif callable(subcast):
+
+        class SubcastField(ma.fields.Field):
+            def _deserialize(self, value, *args, **kwargs):
+                func = typing.cast(typing.Callable[..., _T], subcast)
+                return func(value)
+
+        inner_field = SubcastField
+    else:
+        inner_field = ma.fields.Field
+    return inner_field
+
+
 def _make_list_field(*, subcast: typing.Optional[type], **kwargs) -> ma.fields.List:
-    inner_field = ma.Schema.TYPE_MAPPING[subcast] if subcast else ma.fields.Field
+    inner_field = _make_subcast_field(subcast)
     return ma.fields.List(inner_field, **kwargs)
 
 
@@ -159,23 +209,30 @@ def _preprocess_list(
 def _preprocess_dict(
     value: typing.Union[str, typing.Mapping],
     *,
-    subcast_key: typing.Optional[Subcast] = None,
+    subcast_keys: typing.Optional[Subcast] = None,
+    subcast_key: typing.Optional[Subcast] = None,  # Deprecated
     subcast_values: typing.Optional[Subcast] = None,
     **kwargs,
 ) -> typing.Mapping:
     if isinstance(value, Mapping):
         return value
 
+    if subcast_key:
+        warnings.warn("`subcast_key` is deprecated. Use `subcast_keys` instead.", DeprecationWarning)
+    subcast_keys_instance: ma.fields.Field = _make_subcast_field(subcast_keys or subcast_key)(**kwargs)
+    subcast_values_instance: ma.fields.Field = _make_subcast_field(subcast_values)(**kwargs)
+
     return {
-        (subcast_key(key.strip()) if subcast_key else key.strip()): (
-            subcast_values(val.strip()) if subcast_values else val.strip()
-        )
+        subcast_keys_instance.deserialize(key.strip()): subcast_values_instance.deserialize(val.strip())
         for key, val in (item.split("=", 1) for item in value.split(",") if value)
     }
 
 
 def _preprocess_json(value: str, **kwargs):
-    return pyjson.loads(value)
+    try:
+        return pyjson.loads(value)
+    except pyjson.JSONDecodeError as error:
+        raise ma.ValidationError("Not valid JSON.") from error
 
 
 _EnumT = typing.TypeVar("_EnumT", bound=Enum)
@@ -260,6 +317,8 @@ class URLField(ma.fields.URL):
 
 class PathField(ma.fields.Str):
     def _deserialize(self, value, *args, **kwargs) -> Path:
+        if isinstance(value, Path):
+            return value
         ret = super()._deserialize(value, *args, **kwargs)
         return Path(ret)
 
@@ -286,8 +345,15 @@ class Env:
     str = _field2method(ma.fields.Str, "str")
     float = _field2method(ma.fields.Float, "float")
     decimal = _field2method(ma.fields.Decimal, "decimal")
-    list = _field2method(_make_list_field, "list", preprocess=_preprocess_list)
-    dict = _field2method(ma.fields.Dict, "dict", preprocess=_preprocess_dict)
+    list = _field2method(
+        _make_list_field, "list", preprocess=_preprocess_list, preprocess_kwarg_names=("subcast", "delimiter")
+    )
+    dict = _field2method(
+        ma.fields.Dict,
+        "dict",
+        preprocess=_preprocess_dict,
+        preprocess_kwarg_names=("subcast", "subcast_keys", "subcast_key", "subcast_values"),
+    )
     json = _field2method(ma.fields.Field, "json", preprocess=_preprocess_json)
     datetime = _field2method(ma.fields.DateTime, "datetime")
     date = _field2method(ma.fields.Date, "date")
@@ -332,9 +398,10 @@ class Env:
         if path is None:
             # By default, start search from the same directory this function is called
             current_frame = inspect.currentframe()
-            if not current_frame:
+            if current_frame is None:
                 raise RuntimeError("Could not get current call frame.")
-            frame = typing.cast(types.FrameType, current_frame.f_back)
+            frame = current_frame.f_back
+            assert frame is not None
             caller_dir = Path(frame.f_code.co_filename).parent.resolve()
             start = caller_dir / ".env"
         else:
@@ -432,10 +499,12 @@ class Env:
         if hasattr(value, "strip"):
             expand_match = self.expand_vars and _EXPANDED_VAR_PATTERN.match(value)
             if expand_match:  # Full match expand_vars - special case keep default
-                proxied_key = expand_match.groups()[0]
-                subs_default = expand_match.groups()[1]
+                proxied_key: _StrType = expand_match.groups()[0]
+                subs_default: typing.Optional[_StrType] = expand_match.groups()[1]
                 if subs_default is not None:
                     default = subs_default[2:]
+                elif value == default:  # if we have used default, don't use it recursively
+                    default = ma.missing
                 return (key, self._get_from_environ(proxied_key, default, proxied=True)[1], proxied_key)
             expand_search = self.expand_vars and _EXPANDED_VAR_PATTERN.search(value)
             if expand_search:  # Multiple or in text match expand_vars - General case - default lost
